<?php

namespace Growmatik\Admin;

class Feedback {

	public function __construct() {
		// Do not show feedback modal if not integrated yet.
		if ( ! get_option( 'growmatik_site_id', false ) ) {
			return;
		}

		add_action( 'current_screen', array( $this, 'init' ) );
		add_action( 'wp_ajax_growmatik_feedback', array( $this, 'send' ) );
	}

	public function init() {
		if ( ! $this->is_plugins_page() ) {
			return;
		}

		add_action( 'admin_enqueue_scripts', array( $this, 'enueue_scripts' ) );
		add_action( 'admin_footer', array( $this, 'render_modal' ) );
	}

	public function enueue_scripts() {
		wp_enqueue_script( 'growmatik-feedback' );
		wp_enqueue_style( 'growmatik-feedback' );
	}

	private function is_plugins_page() {
		// We are not showing feedback modal for network.
		return in_array( get_current_screen()->id, array( 'plugins' ), true );
	}

	public function render_modal() {
		$deactivation_reasons = array(
			// we dont need it anymore: 'not_using'              => __( 'Didn\'t use it', 'growmatik' ),
			'company_closed'         => __( 'Company Closed', 'growmatik' ),
			'better_solution'        => __( 'I found a better solution', 'growmatik' ),
			'too_difficult'          => __( 'Too difficult to figure out', 'growmatik' ),
			'lack_feature'           => __( 'Lack of features', 'growmatik' ),
			'meeting_my_needs'       => __( 'Doesn\'t meet my needs', 'growmatik' ),
			'cost'                   => __( 'Cost too much', 'growmatik' ),
			'lack_integration'       => __( 'Lack of integration with my tools', 'growmatik' ),
			'terms'                  => __( 'I am not down with your terms of use', 'growmatik' ),
			'temporary_deactivation' => __( 'It\'s a temporary deactivation', 'growmatik' ),
			'other'                  => __( 'Other', 'growmatik' ),
		);

		?>
		<div id="growmatik-modal-bg" style="display: none;">
			<div id="growmatik-feedback-modal">
				<div class="growmatik-feedback-modal-inner">
					<h2><?php esc_html_e( 'If you have a moment, please tell us why you are deactivating:', 'growmatik' ); ?></h2>

					<div class="growmatik-question-row">
						<h4>
							<?php esc_html_e( '1. Why did you cancel your account?' ); ?>
							<span class="growmatik-hint" style="display:none;"><?php esc_html_e( '(required)', 'growmatik' ); ?></span>
						</h4>
						<?php
						foreach ( $deactivation_reasons as $value => $label ) {
							?>
							<div class="option-row">
								<input type="checkbox" name="growmatik-deactivation-reason" id="<?php echo esc_attr( $value ); ?>" value="<?php echo esc_attr( $value ); ?>" style="margin: 0px">
								<label for="<?php echo esc_attr( $value ); ?>"><?php echo esc_html( $label ); ?></label>
							</div>
							<?php
						}
						?>
					</div>
					<div class="growmatik-question-row">
						<h4>
							<?php esc_html_e( '2. Can you explain more? What could we do to improve?' ); ?>
							<span class="growmatik-explanation"><?php esc_html_e( '(optional)', 'growmatik' ); ?></span>
							<div class="alert alert-danger growmatik-err-note" style="display:none;">Please tell us why:</div>
						</h4>
						<textarea name="growmatik-deactivation-note" id="" rows="4"></textarea>
					</div>
					<div class="growmatik-question-row">
						<input type="checkbox" name="growmatik-deactivation-contact" id="growmatik-deactivation-contact">
						<label for="growmatik-deactivation-contact"><?php esc_html_e( 'Can we reach out to you later and discuss why you canceled your account?', 'growmatik' ); ?></label>
					</div>
					<div class="growmatik-question-row">
						<button id="growmatik-send-modal" type="button" class="button button-secondary" data-nonce="<?php echo esc_attr( wp_create_nonce( 'growmatik_feedback' ) ); ?>">
							<?php esc_html_e( 'Submit and deactivate', 'growmatik' ); ?>
						</button>
						<button id="growmatik-discard-modal" type="button" class="button button-primary">
							<?php esc_html_e( 'Discard', 'growmatik' ); ?>
						</button>
					</div>
				</div>
			</div>
		</div>
		<script>

		</script>
		<?php
	}

	public function send() {

		if ( ! isset( $_POST['n'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['n'] ) ), 'growmatik_feedback' ) ) {
			wp_send_json_error();
		}

		$reasons = isset( $_POST['reasons'] ) ? $_POST['reasons'] : null; // phpcs:ignore
		$note    = isset( $_POST['note'] ) ? sanitize_text_field( wp_unslash( $_POST['note'] ) ) : null;
		$email   = null;

		if ( isset( $_POST['contact'] ) && 'false' != sanitize_text_field( wp_unslash( $_POST['contact'] ) ) ) { // phpcs:ignore
			$email = wp_get_current_user()->user_email;
		}

		$variables_types = array(
			'siteId'  => 'ID!',
			'reasons' => '[String!]',
			'note'    => 'String',
			'contact' => 'String',
		);

		$data = array(
			'siteId'  => get_option( 'growmatik_site_id', null ),
			'reasons' => $reasons,
			'note'    => $note,
			'contact' => $email,
		);

		// We don't prevent user from deactivating plugin on failure.
		\Growmatik\GraphQL_Client::make()->make_mutation( 'deactivateFeedbacks', $variables_types, 'success', $data )->execute();

		wp_send_json_success();
	}
}
