<?php

/**
 * Plugin Name:       Growmatik - Marketing Automation and Personalization
 * Plugin URI:        growmatik.ai
 * Description:       Marketing automation assistant to help you understand your users’ behavior, personalize their experience across their journey and help you acquire, nurture, convert and retain them.
 * Version:           2.7.0
 * Author:            Artbees
 * Author URI:        artbees.net
 * License:           GPL-3
 * License URI:       https://www.gnu.org/licenses/gpl-3.0.txt
 * Text Domain:       growmatik
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/** @define "plugin_dir_path( __FILE__ )" "" */
require_once plugin_dir_path( __FILE__ ) . 'vendor/autoload.php';

register_activation_hook( __FILE__, 'growmatik_activation' );
new Growmatik\Rewrite_Rules_Manager();

function growmatik_activation() {
	set_transient( 'growmatik_activation_redirect', true, MINUTE_IN_SECONDS );
}

add_action( 'plugins_loaded', 'growmatik_load' );

function growmatik_load() {
	new Growmatik\Admin\Init();
	new Growmatik\Admin\Notices();
	new Growmatik\Admin\Integration();
	new Growmatik\Admin\Data_Manager();
	new Growmatik\Admin\Smart_Rating();
	new Growmatik\Assets_Manager();

	if ( ! Growmatik\Admin\Integration::is_integrated() ) {
		return;
	}

	new Growmatik\Admin\Email_Consent();
	new Growmatik\Admin\Health_Check();
	new Growmatik\Front\Init();
	new Growmatik\Controller\Redirect_Controller();
	new Growmatik\Controller\Unsubscribe_Controller();
	new Growmatik\Coupon_Handler();
	new Growmatik\Personalizer_Security();
	new Growmatik\Form_Integration\Init();
	new Growmatik\Woocommerce\Init();
	new Growmatik\EDD\Init();
	new Growmatik\EDD2\Init();
	new Growmatik\Event_Handler();

	// Init after Ecommerce platforms register their filters.
	new Growmatik\Modification_Handler();
}
