<?php
namespace Growmatik\Form_Integration\Raven;

use JupiterX_Core\Raven\Modules\Forms\Actions\Action_Base;
use Elementor\Repeater;
use Elementor\Controls_Manager;
use Growmatik\Form_Integration\Integration;

class Raven_Form_Growmatik_Action extends Action_Base {

	private $growmatik_tags, $attributes_config, $form_fields_config; //phpcs:ignore
	private $all_attributes = array();

	public function __construct() {
		add_action( 'elementor/element/raven-form/section_settings/after_section_end', array( $this, 'update_controls' ) );
	}

	public function get_name() {
		return 'growmatik';
	}

	public function get_title() {
		return __( 'Growmatik', 'jupiterx-core' );
	}

	public function update_growmatik_attributes() {
		$this->all_attributes = Integration::instance()->get_all_attributes();
		$this->growmatik_tags = Integration::instance()->get_tags();
	}

	private function set_controls_config() {

		$this->attributes_config = array(
			'name'    => 'growmatik_attribute',
			'label'   => __( 'Attribute', 'growmatik' ),
			'type'    => Controls_Manager::SELECT,
			'options' => array( 'none' => __( '- None -', 'growmatik' ) ) + $this->all_attributes,
			'default' => 'none',
		);

		$this->form_fields_config = array(
			'name'    => 'growmatik_form_field',
			'label'   => __( 'Form Field', 'growmatik' ),
			'type'    => Controls_Manager::SELECT,
			'options' => array(// Will be updated by JS while changing form fields.
				'none' => __( '- None -', 'growmatik' ),
			),
			'default' => 'none',
		);
	}

	private function register_controls_by_add_control() {
		$repeater = new Repeater();

		$repeater->add_control(
			'growmatik_attribute',
			$this->attributes_config
		);

		$repeater->add_control(
			'growmatik_form_field',
			$this->form_fields_config
		);

		return $repeater->get_controls();
	}

	public function update_controls( $widget ) {
		$this->update_growmatik_attributes();
		$this->set_controls_config();

		$widget->start_controls_section(
			'section_growmatik',
			array(
				'label'     => __( 'Growmatik', 'jupiterx-core' ),
				'condition' => array(
					'actions' => $this->get_name(),
				),
			)
		);

		$widget->add_control(
			'growmatik_form_name',
			array(
				'type'    => 'text',
				'label'   => __( 'Form Name', 'gromatik' ),
				'default' => __( 'New Form', 'growmatik' ),
			)
		);

		$widget->add_control(
			'growmatik_form_tags',
			array(
				'type'        => 'select2',
				'label'       => __( 'Tags', 'growmatik' ),
				'description' => __( 'Add comma separated tags', 'growmatik' ),
				'multiple'    => true,
				'options'     => $this->growmatik_tags,
			)
		);

		$widget->add_control(
			'gromatik_heading_field_mapping',
			array(
				'type'  => 'heading',
				'label' => __( 'Field Mapping', 'growmatik' ),
			)
		);

		$repeater_control_args = array(
			'name'          => 'growmatik_mapping_fields',
			'type'          => 'repeater',
			'prevent_empty' => true,
			'default'       => array(
				array(
					'growmatik_attribute'  => 'none',
					'growmatik_form_field' => 'none',
				),
			),
		);

		$repeater_control_args['fields'] = $this->register_controls_by_add_control();

		$widget->add_control(
			'growmatik_mapping_fields',
			$repeater_control_args
		);

		$widget->end_controls_section();
	}

	public static function run( $ajax_handler ) {
		$form     = $ajax_handler->form;
		$settings = $form['settings'];

		$all_fields = array();
		$site_id    = get_option( 'growmatik_site_id' );
		$tags       = isset( $settings['growmatik_form_tags'] ) ? $settings['growmatik_form_tags'] : '';
		$form_name  = isset( $settings['growmatik_form_name'] ) ? $settings['growmatik_form_name'] : '';
		$vals       = array( 'on', true, 'true', 'checked', '1', 1, 'granted' );

		// Get value of default and custom mapped fields.
		foreach ( $settings['growmatik_mapping_fields'] as $field_key => $value ) {
			if ( ! isset( $value['growmatik_form_field'] ) ) {
				continue;
			}

			$field_id = $value['growmatik_form_field'];

			if ( $field_id ) {
				$growmatik_field = str_replace( 'growmatik-', '', $value['growmatik_attribute'] );

				if ( ! empty( $growmatik_field ) && 'none' !== $growmatik_field ) {

					if ( in_array( $growmatik_field, array( '012', '013' ), true ) ) {
						$ajax_handler->record['fields'][ $field_id ] = in_array( $ajax_handler->record['fields'][ $field_id ], $vals, true )
						? 'granted' : 'denied';
					}

					$field = array(
						'key'   => $growmatik_field,
						'value' => $ajax_handler->record['fields'][ $field_id ],
						'type'  => Integration::instance()->get_attribute_type( $growmatik_field ),
					);

					array_push( $all_fields, $field );
				}
			}
		}

		$form_data = array(
			'siteId'   => $site_id,
			'formName' => $form_name,
			'tags'     => $tags,
			'formData' => $all_fields,
		);

		$response = Integration::instance()->form_submission( $form_data );

		if ( is_wp_error( $response ) ) {
			error_log( __( 'Growmatik: Internal server error.', 'growmatik' ) ); // phpcs:ignore
		} elseif ( isset( $response['errors'] ) && isset( $response['error']['api_error'] ) ) {
			error_log( (string) $response['error']['api_error'][0] ); // phpcs:ignore
		}
	}
}
